/**
 * Copyright (c) 2004-2013, Abel Hegedus and Daniel Varro
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *   Abel Hegedus - initial API and implementation
 */
package org.eclipse.viatra.transformation.runtime.emf.filters;

import com.google.common.base.Objects;
import java.util.Map;
import java.util.function.Consumer;
import org.eclipse.viatra.query.runtime.api.IPatternMatch;
import org.eclipse.viatra.query.runtime.api.ViatraQueryMatcher;
import org.eclipse.viatra.transformation.evm.api.event.EventFilter;
import org.eclipse.xtext.xbase.lib.CollectionLiterals;
import org.eclipse.xtext.xbase.lib.Functions.Function1;
import org.eclipse.xtext.xbase.lib.IterableExtensions;
import org.eclipse.xtext.xbase.lib.Pair;

/**
 * A EVM filter that uses a parameter-value map that can be used for
 * multiple patterns and rules.
 * 
 * Use ParameterFilterFactory to create easily manage the mapping and
 * create unmodifiable copies to be added to rules.
 * 
 * @author Abel Hegedus
 */
@SuppressWarnings("all")
public class MatchParameterFilter implements EventFilter<IPatternMatch> {
  private Map<String, Object> filterMap;
  
  public MatchParameterFilter(final Map<String, Object> filterMap) {
    this.filterMap = CollectionLiterals.<String, Object>newHashMap();
    this.filterMap.putAll(filterMap);
  }
  
  public MatchParameterFilter(final Pair<String, ?>... parameters) {
    this.filterMap = CollectionLiterals.<String, Object>newHashMap(parameters);
  }
  
  @Override
  public boolean isProcessable(final IPatternMatch eventAtom) {
    final Function1<String, Boolean> _function = (String it) -> {
      return Boolean.valueOf((this.filterMap.containsKey(it) && (!Objects.equal(this.filterMap.get(it), eventAtom.get(it)))));
    };
    return IterableExtensions.isEmpty(IterableExtensions.<String>filter(eventAtom.parameterNames(), _function));
  }
  
  public <Match extends IPatternMatch, Matcher extends ViatraQueryMatcher<Match>> Match toMatch(final Matcher matcher) {
    Match _xblockexpression = null;
    {
      final Match match = matcher.newEmptyMatch();
      final Consumer<String> _function = (String it) -> {
        boolean _containsKey = this.filterMap.containsKey(it);
        if (_containsKey) {
          match.set(it, this.filterMap.get(it));
        }
      };
      matcher.getParameterNames().forEach(_function);
      _xblockexpression = match;
    }
    return _xblockexpression;
  }
}
